@@ -222,11 +222,11 @@ class InstanceValidation(BasicValidation):
                     self._replacement = instance
                     return True
 
-            self._field_errors.append(InstanceValidationError(
-                value_repr=get_value_repr(value), value_type=type(value),
-                annotation=annotation, exception=exception, errors=errors
-            ))
-            return False
+                self._field_errors.append(InstanceValidationError(
+                    value_repr=get_value_repr(value), value_type=type(value),
+                    annotation=annotation, exception=exception, errors=errors
+                ))
+                return False
 
         return super()._is_instance(value, annotation)
 
@@ -302,14 +302,10 @@ class TypingValidation(InstanceValidation):
 
             if self._is_supported_alias(str_annotation):
 
-                try:
-                    is_instance = self._get_alias_method(str_annotation)
-
+                is_instance = self._get_alias_method(str_annotation)
+                if is_instance is not None:
                     return is_instance(value, annotation)
 
-                except Exception:
-                    pass
-
             exception = TypeError('Alias is not supported!')
             self._field_errors.append(TypingValidationError(
                 value_repr=get_value_repr(value), value_type=type(value),
@@ -395,6 +391,12 @@ class TypingValidation(InstanceValidation):
                         self._replacement = False
                     new_value.append(item_value)
                 else:
+                    if self._field_errors:
+                        last = self._field_errors[-1]
+                        last_is_basic = type(last) == BasicValidationError
+                        if last_is_basic:
+                            self._field_errors = self._field_errors[:-1]
+
                     self._field_errors.append(ListValidationError(
                         value_repr=get_value_repr(item_value),
                         value_type=type(item_value), item_index=i,
@@ -482,44 +484,3 @@ class ValidatedDC(TypingValidation):
             nested_validated_dc.update(validated_dc.get_nested_validated_dc())
 
         return nested_validated_dc
-
-
-# ----------------------------------------------------------------------------
-
-
-if __name__ == "__main__":
-
-    print(get_value_repr(123456789012345678901234))
-
-    @dataclass
-    class SimpleInt(ValidatedDC):
-        i: int
-
-    @dataclass
-    class SimpleStr(ValidatedDC):
-        s: str
-
-    @dataclass
-    class SimpleDict(ValidatedDC):
-        d: dict
-
-    @dataclass
-    class SimpleUnion(ValidatedDC):
-        u: List[List[Union[SimpleInt, SimpleStr, SimpleDict]]]
-
-    u = SimpleUnion(u=[
-        [{'i': 1}, {'s': '1'}, {'i': 2}, {'d': {}}],
-        [{'i': 5}, {'s': '6'}, {'i': 7}, {'d': {8: 8}}],
-    ])
-
-    print(u.get_errors())
-    # None
-
-    print(u)
-    # SimpleUnion(u=[[SimpleInt(i=1), SimpleStr(s='1'), SimpleInt(i=2),
-    #             SimpleDict(d={})], [SimpleInt(i=5), SimpleStr(s='6'),
-    #             SimpleInt(i=7), SimpleDict(d={8: 8})]])
-
-    print(SimpleUnion.get_nested_validated_dc())
-    # {<class '__main__.SimpleInt'>, <class '__main__.SimpleStr'>,
-    #  <class '__main__.SimpleDict'>}
